;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "diredfd" "20241209.623"
  "Dired functions and settings to mimic FD/FDclone."
  '((emacs "28.1"))
  :url "https://github.com/knu/diredfd.el"
  :commit "d789710c7e9699dae6ca87dcbfc27641a85fa3b6"
  :revdesc "d789710c7e96"
  :keywords '("unix" "directories" "dired")
  :authors '(("Akinori MUSHA" . "knu@iDaemons.org"))
  :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
